@@ -17,10 +17,10 @@ def from_spark_to_pandas_df_using_disk(df, path='/tmp/tmp_csv_df'):
     return result
 
 def init_spark():
-    return spark_initializer("Test-model", get_args(), additional_config=[('spark.sql.execution.arrow.enabled', True)])
+    return spark_initializer("Ds-io", get_args(), additional_config=[('spark.sql.execution.arrow.enabled', True)])
 
 
-def get_path():
-    df = ds_initializer.load_dataset(sc=init_spark(), read_all=False)
+def get_path(name):
+    df = ds_initializer.load_dataset(sc=init_spark(), name=name read_all=False)
     return from_spark_to_pandas_df_using_disk(df)
 
